@@ -376,7 +376,11 @@ class Window:
             dc = win32gui.GetWindowDC(self.hwnd)
             colorref = win32gui.GetPixel(dc, x + 8, y + 8)
         except:
-            raise(Exception, "Could not get pixel")
+            if self.is_minimized:
+                win32gui.ShowWindow(self.hwnd, win32con.SW_RESTORE)
+                return self.pixel(x, y)
+            else:
+                raise Exception("Could not get pixel")
         win32gui.DeleteDC(dc)
         r, g, b = rgbint2rgbtuple(colorref)
         return Color(r, g, b)
@@ -481,7 +485,25 @@ class Window:
                     # Fortunately, this seems to work even with windows that have no Minimize button.
                     # Note that if we tried to hide the window with SW_HIDE,
                     # it would disappear from the Task Bar as well.
-                    win32gui.ShowWindow(hwnd, win32con.SW_FORCEMINIMIZE)
+                    try:
+                        win32gui.ShowWindow(hwnd, win32con.SW_FORCEMINIMIZE)
+                    except:
+                        raise Exception(
+                            """
+                            Could not minimize the follow window:
+                            hwnd - {}
+                            text - {}
+                            class - {}
+                            visible - {}
+                            marked always topmost - {}
+                            """.format(
+                                hwnd,
+                                win32gui.GetWindowText(hwnd),
+                                win32gui.GetClassName(hwnd),
+                                win32gui.IsWindowVisible(hwnd),
+                                win32gui.GetWindowLong(hwnd, win32con.GWL_EXSTYLE) & win32con.WS_EX_TOPMOST
+                            )
+                        )
 
 
 def points_to_region(p1, p2=None):
